import { NextConfig } from 'next';

interface WithSettleMintOptions {
    disabled?: boolean;
    output?: "standalone" | "export" | "static" | "server" | "experimental-server" | "experimental-static";
}
/**
 * Modifies the passed in Next.js configuration with SettleMint-specific settings
 * @param nextConfig - The original Next.js configuration
 * @param options - Options for customizing the SettleMint configuration
 * @returns The modified Next.js configuration
 * @throws {Error} If the SettleMint configuration cannot be read or processed
 *
 * @example
 * ```typescript
 * const modifiedConfig = withSettleMint(nextConfig, { output: 'standalone' });
 * ```
 */
declare function withSettleMint<C extends NextConfig>(nextConfig: C, { disabled, output }?: WithSettleMintOptions): C;

export { withSettleMint };
